@@ -51,3 +51,11 @@ void user_unif_set_generator(int gener, void (*selected_init)(unsigned int), dou
 
 void (*WELL_get_set_entry_point)(void (* user_unif_set_generator)());
 
+/* Functions accessed from .C() */
+void set_noop();
+void current_generator(int *pgener);
+void put_user_unif_set_generator();
+
+/* Functions to be found by RNGkind() */
+double *user_unif_rand(void);
+void user_unif_init(unsigned int seed);
